/************************************************************************************/
/*  Copyright (C)           Microcyber Inc. All Rights Reserved                     */
/*  Product:                NCS-TT106 Profibus PA                                   */
/*                                                                                  */
/*  Device:                 NCS-TT106 TEMPERATURE DEVICE for PROFIBUS PA            */
/*  Description:            Device Description File                                 */
/*  Dictionary:             SIPADC01.dct                                            */
/*                                                                                  */
/*  Revision:  1.0                                                                  */
/*  Date:      2010-8-21                                                            */
/*  Author:    Ning Dekui                                                           */
/************************************************************************************/
MANUFACTURER            0x16c,
DEVICE_TYPE             0x01,
DEVICE_REVISION         0x01,
DD_REVISION             0x01

//#define _NCS_TT106
#define DEVICE_TYPE "NCS_TT106"

#include "SI_FileM.inc"
#include "SI_HlpM.inc"
#include "SI_OptM.inc"
#include "SIPAST_CommError.inc"

/*
#include "SI_MainMenu.inc"
#include "SI_ViewM.inc"
*/

#include "defmacros.inc"
#include "Phys_Blk.inc"
#include "AI2_Blk1.inc"
#include "MC_YT.inc"
#include "Table.inc"


/***********************************************************************/
/*    Transducer Block 1                                               */
/***********************************************************************/

BLOCK trans1_TT_1
{
    TYPE    TRANSDUCER;
    NUMBER    1;
}

trans1_TT_1_blk_reserve                            LIKE VARIABLE    phys_blk_reserve
{
}

VARIABLE trans1_TT_1_blk_object
{
    LABEL       [blk_block_object];
    HELP        [blk_block_object_help];
    CLASS       DEVICE;
    HANDLING    READ;
    TYPE        ENUMERATED(1)
    {
        {    3,    [blk_block_object_TRANSDUCER]        }
    }
}

VARIABLE trans1_TT_1_blk_parent_class
{
    LABEL       [blk_parent_class];
    HELP        [trans_blk_parent_class_help];
    CLASS       DEVICE;
    HANDLING    READ;
    TYPE        ENUMERATED(1)
    {
        {    2,    [trans_blk_parent_class_TEMP]    }
    }
}

VARIABLE trans1_TT_1_blk_class
{
    LABEL       [blk_class];
    HELP        [trans_blk_class_help];
    CLASS       DEVICE;
    HANDLING    READ;
    TYPE        ENUMERATED(1)
    {
        DEFAULT_VALUE    18;
        {    1,      [trans_temp_blk_class_TC]     },
        {    2,      [trans_temp_blk_class_RTD]    },
        {    3,      [trans_temp_blk_class_PYR]    },
        {    16,     "TC + DC U"                   },
        {    17,     "RTD + R"                     },
        {    18,     "TC + RTD + R + DC U"         },
        {    250,    [not_used]                    },
        {    251,    [none]                        },
        {    252,    [unknown]                     },
        {    253,    [special]                     }
    }
}

//trans1_TT_1_blk_dd_reference                      LIKE VARIABLE    phys_blk_dd_reference
//{
//}

trans1_TT_1_blk_devrev                      LIKE VARIABLE    phys_blk_devrev
{
}

trans1_TT_1_blk_devrevcomp                      LIKE VARIABLE    phys_blk_devrevcomp
{
}

trans1_TT_1_blk_dd_rev                            LIKE VARIABLE    phys_blk_dd_rev
{
}

trans1_TT_1_blk_profile                           LIKE VARIABLE    phys_blk_profile
{
}

trans1_TT_1_blk_profile_rev                       LIKE VARIABLE    phys_blk_profile_rev
{
}

trans1_TT_1_blk_execution_time                    LIKE VARIABLE    phys_blk_execution_time
{
}

trans1_TT_1_blk_num_parameters                    LIKE VARIABLE    phys_blk_num_parameters
{
}

trans1_TT_1_blk_index_view_1                      LIKE VARIABLE    phys_blk_index_view_1
{
}

trans1_TT_1_blk_num_view_lists                    LIKE VARIABLE    phys_blk_num_view_lists
{
}

trans1_TT_1_st_rev                                LIKE VARIABLE    phys_st_rev
{
}

trans1_TT_1_tag_desc                              LIKE VARIABLE    phys_tag_desc
{
    REDEFINE LABEL        [MC_trans1_tag_desc];
    TYPE                  ASCII (32)
    {
        REDEFINE DEFAULT_VALUE  "";
    }
}

trans1_TT_1_strategy                              LIKE VARIABLE    phys_strategy
{
}

trans1_TT_1_alert_key                             LIKE VARIABLE    phys_alert_key
{
}

trans1_TT_1_target_mode                           LIKE VARIABLE    phys_target_mode
{
}

trans1_TT_1_actual_mode                           LIKE VARIABLE    phys_actual_mode
{
}

trans1_TT_1_permitted_mode                        LIKE VARIABLE    phys_permitted_mode
{
}

trans1_TT_1_normal_mode                           LIKE VARIABLE    phys_normal_mode
{
}

trans1_TT_1_current_state_alarm_sum               LIKE VARIABLE    phys_current_state_alarm_sum
{
}

trans1_TT_1_unacknowledged_state_alarm_sum        LIKE VARIABLE    phys_unacknowledged_state_alarm_sum
{
}

trans1_TT_1_unreported_state_alarm_sum            LIKE VARIABLE    phys_unreported_state_alarm_sum
{
}

trans1_TT_1_disabled_state_alarm_sum              LIKE VARIABLE    phys_disabled_state_alarm_sum
{
}


/*---------------------------------------------------------------------*/
/*    Transducer Block: Temperature Transmitter                        */
/*---------------------------------------------------------------------*/

VARIABLE trans1_TT_1_lin_type             /* index 14 */
{
    LABEL       [trans_lin_type];
    HELP        [trans_lin_type_help];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    102;
        { 0,      [linear]           },
        { 102,    [RTD_Pt100]        },
        { 105,    [RTD_Pt1000]       },
        { 240,    [MC_RTD_Cu50]      },
        { 127,    [RTD_Cu100]        },

        { 128,    [TC_type_B]        },
        { 131,    [TC_type_E]        },
        { 133,    [TC_type_J]        },
        { 134,    [TC_type_K]        },
        { 135,    [TC_type_N]        },
        { 136,    [TC_type_R]        },
        { 137,    [TC_type_S]        },
        { 138,    [TC_type_T]        },
        { 241,    "Custom RTD"       },
        { 242,    "Custom TC"        }
    }
    POST_EDIT_ACTIONS
    {
        method_tt_1_lin_type
    }
}

VARIABLE trans1_TT_1_primary_value
{
    LABEL       [trans_value];
    HELP        [trans_temp_value_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }
}

VARIABLE trans1_TT_1_primary_value_status_quality
{
    LABEL       [status_quality];
    HELP        [value_status_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
}

trans1_TT_1_primary_value_status_limit            LIKE VARIABLE    trans1_TT_1_primary_value_status_quality
{
    REDEFINE LABEL       [status_limit];
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_TT_1_primary_value_unit
{
    LABEL       [digital_units];
    HELP        [MC_digital_units_help];
    CLASS       DEVICE;
    HANDLING    READ & WRITE;
    TYPE        ENUMERATED (2)
    {
        IF (trans1_TT_1_lin_type==0 && trans1_TT_1_input_range==0)
        {
            { 1243, [unit_1243],    [unit_1243_help] }
        }
        ELSE
        {
            IF (trans1_TT_1_lin_type==0 && (trans1_TT_1_input_range==128 || trans1_TT_1_input_range==129))
            {
                { 1281, [unit_1281],    [unit_1281_help] }
            }
            ELSE
            {
                IF (trans1_TT_1_lin_type>0)
                {
                    { 1000, [unit_1000],    [unit_1000_help] },
                    { 1001, [unit_1001],    [unit_1001_help] },
                    { 1002, [unit_1002],    [unit_1002_help] },
                    { 1003, [unit_1003],    [unit_1003_help] }
                }
            }
        }
    
    DEFAULT_VALUE  IF (trans1_TT_1_lin_type == 0)
                   {
                       IF (trans1_TT_1_input_range==0)
                       {1243;}
                       ELSE
                       {1281;}
                   } 
                   ELSE {1001;}
    }
//    IF (trans1_TT_1_lin_type == 0){1281;} ELSE {1001;}
//    POST_EDIT_ACTIONS
//    {
//        method_TT_1_primary_value_unit

//    }
    POST_WRITE_ACTIONS
    {
        method_post_write_read_device_values
    }
}

VARIABLE trans1_TT_1_secondary_value_1
{
    LABEL       [trans_temp_secondary_value1];
    HELP        [trans_temp_secondary_value1_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
    }
}

VARIABLE trans1_TT_1_secondary_value_1_status_quality
{
    LABEL       [status_quality];
    HELP        [value_status_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        STATUS_OUTPUT_NO_RCAS
    }
}

trans1_TT_1_secondary_value_1_status_limit        LIKE VARIABLE    trans1_TT_1_secondary_value_1_status_quality
{
    REDEFINE LABEL       [status_limit];
    REDEFINE TYPE        ENUMERATED (1)
    {
        STATUS_OUTPUT_LIMIT
    }
}

VARIABLE trans1_TT_1_input_range
{
    LABEL       [trans_temp_input_range];
    HELP        [trans_temp_input_range_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    128;
        {    0,      [MC_100MV]          },
        {    128,    [MC_500Ohm]         },
        {    129,    [MC_4000Ohm]        }
    }
    HANDLING    IF (trans1_TT_1_lin_type == 0)
                {
                    READ & WRITE;
                }
                ELSE
                {
                    READ;
                }
    POST_EDIT_ACTIONS
    {
        method_tt_1_input_range
    }
}

VARIABLE trans1_TT_1_bias_1
{
    LABEL       "Offset"; //[trans_temp_bias_1];
    HELP        [trans_temp_bias_1_help];
    CLASS       DEVICE;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_upper_sensor_limit
{
    LABEL       [trans_sensor_upper_limit];
    HELP        [trans_sensor_upper_limit_help];
    CLASS       DEVICE;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    850.00;
    }
    HANDLING    READ;
}

VARIABLE trans1_TT_1_lower_sensor_limit
{
    LABEL       [trans_sensor_lower_limit];
    HELP        [trans_sensor_lower_limit_help];
    CLASS       DEVICE;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    -200.00;
    }
    HANDLING    READ;
}

VARIABLE trans1_TT_1_input_fault_gen
{
    LABEL       [trans_temp_input_fault];
    HELP        [trans_temp_input_fault_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        BIT_ENUMERATED (1)
    {
        { 0x00,    [trans_temp_input_fault_OK]            },
        { 0x01,    [trans_temp_input_fault_RJ_ERR]        },
        { 0x02,    [trans_temp_input_fault_HW_ERR]        }
        /*{ 0X40, [MC_Comm_Err]                        }*/
    }
    STYLE       "MULTILINE 16 3" ;
}

VARIABLE trans1_TT_1_input_fault_1
{
    LABEL       [trans_temp_input_fault_CH1_FAULT];
    HELP        [trans_temp_input_fault_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    TYPE        BIT_ENUMERATED (1)
    {
        { 0x00,    [trans_temp_input_fault_OK]                },
        { 0x01,    [trans_temp_input_fault_UNDERRANGE]        },
        { 0x02,    [trans_temp_input_fault_OVERRANGE]         },
        { 0x04,    [trans_temp_input_fault_LEAD_BREAK]        },
        { 0x08,    [trans_temp_input_fault_SHORT_CIRCUIT]     },
        { 0X10,    "RJ Underrange"                            },
        { 0X20,    "RJ Overrange"                             }
        //{ 0X40,    "AD Chip Error"                            }
    }
    STYLE       "MULTILINE 16 7" ;
}

VARIABLE trans1_TT_1_sensor_wire_check_1
{
    LABEL       [trans_sensor_wire_check_1];
    HELP        [trans_sensor_wire_check_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (1)
    {
        { 0x00,    [trans_sensor_wire_check_BREAK_ON_SHORT_ON]     },
        { 0x01,    [trans_sensor_wire_check_BREAK_ON_SHORT_OFF]    },
        { 0x02,    [trans_sensor_wire_check_BREAK_OFF_SHORT_ON]    },
        { 0x03,    [MC_disabled]                                   }
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_rj_temp
{
    LABEL       [trans_temp_rj_temp];
    HELP        [trans_temp_rj_temp_help];
    CLASS       DEVICE & DYNAMIC;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1001];CASE 1281: [unit_1001];}
    TYPE        FLOAT
    {
        DEFAULT_VALUE 0.0;
        DISPLAY_FORMAT ".2f";
//        MIN_VALUE SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: 233.15;CASE 1001: -40.0;CASE 1002: -40.0;CASE 1003: 419.67;}
//        MAX_VALUE SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: 385.15;CASE 1001: 85.0;CASE 1002: 185.0;CASE 1003: 644.67;}
    }
}

VARIABLE trans1_TT_1_rj_type
{
    LABEL       [trans_temp_rj_type];
    HELP        [trans_temp_rj_type_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    1;
        {    0,        [MC_trans_temp_rj_type_NONE]   },
        {    1,        [MC_trans_temp_rj_type_INT]    },
        {    2,        [MC_trans_temp_rj_type_Ext_Fixd]    },
        {    3,        [MC_trans_temp_rj_type_Ext_PT100_2W]    }
    }
    HANDLING    IF ((trans1_TT_1_lin_type == 102) || (trans1_TT_1_lin_type == 105) ||
                    (trans1_TT_1_lin_type == 240) || (trans1_TT_1_lin_type == 127) ||
                    (trans1_TT_1_lin_type == 241) || (trans1_TT_1_lin_type == 0))
                {
                    READ;
                }
                ELSE
                {
                    READ & WRITE;
                }
}

VARIABLE trans1_TT_1_external_rj_value
{
    LABEL       [trans_temp_external_rj_value];
    HELP        [trans_temp_external_rj_value_help];
    CLASS       DEVICE;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1001];CASE 1281: [unit_1001];}
    TYPE        FLOAT
    {
//        MIN_VALUE SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: 233.15;CASE 1001: -40.0;CASE 1002: -40.0;CASE 1003: 419.67;CASE 1342: -40.0;}
//        MAX_VALUE SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: 385.15;CASE 1001: 85.0;CASE 1002: 185.0;CASE 1003: 644.67;CASE 1342: 85.0;}
        EDIT_FORMAT "2.2f";
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE 0.0;
    }
    HANDLING    IF (((trans1_TT_1_lin_type >= 128) && (trans1_TT_1_lin_type <= 138)|| (trans1_TT_1_lin_type == 242)) && (trans1_TT_1_rj_type == 2))
                {
                    READ & WRITE;
                }
                ELSE
                {
                    READ;
                }
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: Thermoresistance Temperature Device (RTD)       */
/*---------------------------------------------------------------------*/

VARIABLE trans1_TT_1_sensor_connection
{
    LABEL       [trans_temp_sensor_connection];
    HELP        [trans_temp_sensor_connection_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    1;
        {    0,    [trans_temp_sensor_connection_2_WIRE]        },
        {    1,    [trans_temp_sensor_connection_3_WIRE]        },
        {    2,    [trans_temp_sensor_connection_4_WIRE]        }
    }
    HANDLING    IF ((trans1_TT_1_lin_type == 102) || (trans1_TT_1_lin_type == 105) || 
                    (trans1_TT_1_lin_type == 240) || (trans1_TT_1_lin_type == 127) ||
                    (trans1_TT_1_lin_type == 241) || ((trans1_TT_1_lin_type == 0)&&(trans1_TT_1_input_range==128||trans1_TT_1_input_range==129)))
                {   
                    READ & WRITE;
                }
                ELSE
                {
                    READ;
                }
}

/*---------------------------------------------------------------------*/
/*    Transducer Block: user defined                                   */
/*---------------------------------------------------------------------*/
VARIABLE trans1_TT_1_Cal_Point_Hi
{
    LABEL       [trans_cal_point_hi];
    HELP        [trans_cal_point_hi_help];
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    850.00;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_Cal_Point_Lo
{
    LABEL       [trans_cal_point_lo];
    HELP        [trans_cal_point_lo_help];
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    -200.00;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_Cal_Min_Span
{
    LABEL       [trans_cal_min_span];
    HELP        [trans_cal_min_span_help];
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_Cal_Unit
{
    LABEL       [trans_cal_unit];
    HELP        [trans_cal_unit_help];
    CLASS       DEVICE;
    TYPE        ENUMERATED (2)
    {
        DEFAULT_VALUE    1001;
        { 1001, [unit_1001],    [unit_1001_help] },
        { 1243, [unit_1243],    [unit_1243_help] },
        { 1281, [unit_1281],    [unit_1281_help] }
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_Sensor_Value_1
{
    LABEL       [MC_Sensor_Value_1];
    HELP        [MC_Sensor_Value_1];
    CLASS       DEVICE;
    HANDLING    READ;
    CONSTANT_UNIT SELECT (trans1_TT_1_primary_value_unit) {CASE 1000: [unit_1000];CASE 1001: [unit_1001];CASE 1002: [unit_1002];CASE 1003: [unit_1003];CASE 1243: [unit_1243];CASE 1281: [unit_1281];}
    TYPE        FLOAT
    {
        DISPLAY_FORMAT ".2f";
        DEFAULT_VALUE    0.0;
    }
}


VARIABLE trans1_TT_1_Sensor_Modify
{
    LABEL       "R0 Adjust";
    HELP        "R0 Adjust, Range : 0.9 ~ 1.1";
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    1.0;
        MIN_VALUE        0.9;
        MAX_VALUE        1.1;
        DISPLAY_FORMAT ".6f";
    }
    HANDLING    READ & WRITE;

}

VARIABLE trans1_TT_1_Two_Wires_Comp
{
    LABEL       [MC_two_wires_compe];
    HELP        [MC_two_wires_compe];
    CLASS       DEVICE;
    TYPE        ENUMERATED (1)
    {
        DEFAULT_VALUE    0;
        {    0,    "finished"                },
        {    1,    "Two Wires Zero Comp"     },
        {    2,    "COMP_COLD_TEMP_400R"     },
        {    3,    "COMP_HIGH_TEMP_400R"     },
        {    4,    "COMP_ADC_VAL_400R"       },
        {    5,    "COMP_COLD_TEMP_3200R"    },
        {    6,    "COMP_HIGH_TEMP_3200R"    },
        {    7,    "COMP_ADC_VAL_3200R"      },
        {    8,    "COMP_EXT_PT100_TWO_WIRES_ZERO"      }
//        {    8,    "COMP_RST_COLD_TEMP"      },
//        {    9,    "COMP_RST_HIGH_TEMP"      },
//        {    10,   "COMP_RST_ADC_VAL"        }
    }
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_tdohm_500r
{
    LABEL       "500 Ohm Calibration point";
    HELP        "  ";
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    400.0;
        MIN_VALUE        350.0;
        MAX_VALUE        490.0;
        DISPLAY_FORMAT ".3f";
    }
    CONSTANT_UNIT  "Ohm";
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_tdohm_4000r
{
    LABEL       "4000 Ohm Calibration point";
    HELP        "";
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    3200.0;
        MIN_VALUE        2500.0;
        MAX_VALUE        3900.0;
        DISPLAY_FORMAT ".3f";
    }
    CONSTANT_UNIT  "Ohm";
    HANDLING    READ & WRITE;
}

VARIABLE trans1_TT_1_tdohm_100mv
{
    LABEL       "100 mV Calibration point";
    HELP        " ";
    CLASS       DEVICE;
    TYPE        FLOAT
    {
        DEFAULT_VALUE    100.0;
        MIN_VALUE        40.0;
        MAX_VALUE        110.0;
        DISPLAY_FORMAT ".3f";
    }
    CONSTANT_UNIT  "mV";
    HANDLING    READ & WRITE;
}

/***********************************************************************/
/*    Unit relations                                                   */
/***********************************************************************/

/* Temperature Transducer Block */
UNIT TB_1_CAL_UNIT
{
    trans1_TT_1_Cal_Unit:

    trans1_TT_1_Cal_Point_Hi,
    trans1_TT_1_Cal_Point_Lo,
    trans1_TT_1_Cal_Min_Span
}

/*---------------------------------------------------------------------*/
/*    Commands                                                         */
/*---------------------------------------------------------------------*/
COMMAND read_trans1_TT_1_blk
{
    BLOCK trans1_TT_1;
    INDEX 0;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_blk_reserve,
            trans1_TT_1_blk_object,
            trans1_TT_1_blk_parent_class,
            trans1_TT_1_blk_class,
  //          trans1_TT_1_blk_dd_reference,
            trans1_TT_1_blk_devrev,
            trans1_TT_1_blk_devrevcomp,  
            trans1_TT_1_blk_dd_rev,
            trans1_TT_1_blk_profile,
            trans1_TT_1_blk_profile_rev,
            trans1_TT_1_blk_execution_time,
            trans1_TT_1_blk_num_parameters,
            trans1_TT_1_blk_index_view_1,
            trans1_TT_1_blk_num_view_lists
        }
    }
}

COMMAND read_trans1_TT_1_st_rev
{
    BLOCK trans1_TT_1;
    INDEX 1;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_st_rev
        }
    }
}

COMMAND read_trans1_TT_1_tag_desc
{
    BLOCK trans1_TT_1;
    INDEX 2;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_tag_desc
        }
    }
}

COMMAND write_trans1_TT_1_tag_desc
{
    BLOCK trans1_TT_1;
    INDEX 2;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_tag_desc
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_strategy
{
    BLOCK trans1_TT_1;
    INDEX 3;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_strategy
        }
    }
}

COMMAND write_trans1_TT_1_strategy
{
    BLOCK trans1_TT_1;
    INDEX 3;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_strategy
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_alert_key
{
    BLOCK trans1_TT_1;
    INDEX 4;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_alert_key
        }
    }
}

COMMAND write_trans1_TT_1_alert_key
{
    BLOCK trans1_TT_1;
    INDEX 4;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_alert_key
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_target_mode
{
    BLOCK trans1_TT_1;
    INDEX 5;
    OPERATION  READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_target_mode
        }
    }
}

COMMAND write_trans1_TT_1_target_mode
{
    BLOCK trans1_TT_1;
    INDEX 5;
    OPERATION  WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_target_mode
        }
        REPLY
        {
        }
    }
}


COMMAND read_trans1_TT_1_mode
{
    BLOCK trans1_TT_1;
    INDEX 6;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_actual_mode,
            trans1_TT_1_permitted_mode,
            trans1_TT_1_normal_mode
        }
    }
}

COMMAND read_trans1_TT_1_alarm
{
    BLOCK trans1_TT_1;
    INDEX 7;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_current_state_alarm_sum,
            trans1_TT_1_unacknowledged_state_alarm_sum,
            trans1_TT_1_unreported_state_alarm_sum,
            trans1_TT_1_disabled_state_alarm_sum
        }
    }
}

COMMAND read_trans1_TT_1_primary_value
{
    BLOCK trans1_TT_1;
    INDEX 8;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_primary_value,
            trans1_TT_1_primary_value_status_quality    <0xFC>,
            trans1_TT_1_primary_value_status_limit    <0x03>
        }
    }
}

COMMAND read_trans1_TT_1_primary_value_unit
{
    BLOCK trans1_TT_1;
    INDEX 9;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_primary_value_unit
        }
    }
}

COMMAND write_trans1_TT_1_primary_value_unit
{
    BLOCK trans1_TT_1;
    INDEX 9;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_primary_value_unit
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_secondary_value_1
{
    BLOCK trans1_TT_1;
    INDEX 10;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_secondary_value_1,
            trans1_TT_1_secondary_value_1_status_quality    <0xFC>,
            trans1_TT_1_secondary_value_1_status_limit    <0x03>
        }
    }
}

COMMAND read_trans1_TT_1_input_range
{
    BLOCK trans1_TT_1;
    INDEX 13;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_input_range
        }
    }
}

COMMAND write_trans1_TT_1_input_range
{
    BLOCK trans1_TT_1;
    INDEX 13;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_input_range
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_lin_type
{
    BLOCK trans1_TT_1;
    INDEX 14;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_lin_type
        }
    }
}

COMMAND write_trans1_TT_1_lin_type
{
    BLOCK trans1_TT_1;
    INDEX 14;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_lin_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_bias_1
{
    BLOCK trans1_TT_1;
    INDEX 19;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_bias_1
        }
    }
}

COMMAND write_trans1_TT_1_bias_1
{
    BLOCK trans1_TT_1;
    INDEX 19;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_bias_1
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_upper_sensor_limit
{
    BLOCK trans1_TT_1;
    INDEX 21;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_upper_sensor_limit
        }
    }
}

COMMAND read_trans1_TT_1_lower_sensor_limit
{
    BLOCK trans1_TT_1;
    INDEX 22;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_lower_sensor_limit
        }
    }
}

COMMAND read_trans1_TT_1_input_fault_gen
{
    BLOCK trans1_TT_1;
    INDEX 24;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_input_fault_gen
        }
    }
}

COMMAND read_trans1_TT_1_input_fault_1
{
    BLOCK trans1_TT_1;
    INDEX 25;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_input_fault_1
        }
    }
}

COMMAND read_trans1_TT_1_sensor_wire_check_1
{
    BLOCK trans1_TT_1;
    INDEX 27;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_sensor_wire_check_1
        }
    }
}

COMMAND write_trans1_TT_1_sensor_wire_check_1
{
    BLOCK trans1_TT_1;
    INDEX 27;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_sensor_wire_check_1
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_rj_temp
{
    BLOCK trans1_TT_1;
    INDEX 33;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_rj_temp
        }
    }
}

COMMAND read_trans1_TT_1_rj_type
{
    BLOCK trans1_TT_1;
    INDEX 34;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_rj_type
        }
    }
}

COMMAND write_trans1_TT_1_rj_type
{
    BLOCK trans1_TT_1;
    INDEX 34;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_rj_type
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_external_rj_value
{
    BLOCK trans1_TT_1;
    INDEX 35;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_external_rj_value
        }
    }
}

COMMAND write_trans1_TT_1_external_rj_value
{
    BLOCK trans1_TT_1;
    INDEX 35;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_external_rj_value
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_sensor_connection
{
    BLOCK trans1_TT_1;
    INDEX 36;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_sensor_connection
        }
    }
}

COMMAND write_trans1_TT_1_sensor_connection
{
    BLOCK trans1_TT_1;
    INDEX 36;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_sensor_connection
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_Cal_Point_Hi
{
    BLOCK trans1_TT_1;
    INDEX 62;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Cal_Point_Hi
        }
    }
}

COMMAND write_trans1_TT_1_Cal_Point_Hi
{
    BLOCK trans1_TT_1;
    INDEX 62;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_Cal_Point_Hi
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_Cal_Point_Lo
{
    BLOCK trans1_TT_1;
    INDEX 63;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Cal_Point_Lo
        }
    }
}

COMMAND write_trans1_TT_1_Cal_Point_Lo
{
    BLOCK trans1_TT_1;
    INDEX 63;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_Cal_Point_Lo
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_Cal_Min_Span
{
    BLOCK trans1_TT_1;
    INDEX 64;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Cal_Min_Span
        }
    }
}

COMMAND write_trans1_TT_1_Cal_Min_Span
{
    BLOCK trans1_TT_1;
    INDEX 64;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_Cal_Min_Span
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_Cal_Unit
{
    BLOCK trans1_TT_1;
    INDEX 65;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Cal_Unit
        }
    }
}

COMMAND write_trans1_TT_1_Cal_Unit
{
    BLOCK trans1_TT_1;
    INDEX 65;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_Cal_Unit
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_Sensor_Value_1
{
    BLOCK trans1_TT_1;
    INDEX 67;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Sensor_Value_1
        }
    }
}

COMMAND read_trans1_TT_1_Sensor_Modify
{
    BLOCK trans1_TT_1;
    INDEX 68;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Sensor_Modify
        }
    }
}

COMMAND write_trans1_TT_1_Sensor_Modify
{
    BLOCK trans1_TT_1;
    INDEX 68;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_Sensor_Modify
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_Two_Wires_Comp
{
    BLOCK trans1_TT_1;
    INDEX 69;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_Two_Wires_Comp
        }
    }
}

COMMAND write_trans1_TT_1_Two_Wires_Comp
{
    BLOCK trans1_TT_1;
    INDEX 69;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_Two_Wires_Comp
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_tdohm_500r
{
    BLOCK trans1_TT_1;
    INDEX 70;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_tdohm_500r
        }
    }
}

COMMAND write_trans1_TT_1_tdohm_500r
{
    BLOCK trans1_TT_1;
    INDEX 70;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_tdohm_500r
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_tdohm_4000r
{
    BLOCK trans1_TT_1;
    INDEX 71;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_tdohm_4000r
        }
    }
}

COMMAND write_trans1_TT_1_tdohm_4000r
{
    BLOCK trans1_TT_1;
    INDEX 71;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_tdohm_4000r
        }
        REPLY
        {
        }
    }
}

COMMAND read_trans1_TT_1_tdohm_100mv
{
    BLOCK trans1_TT_1;
    INDEX 72;
    OPERATION READ;
    TRANSACTION
    {
        REQUEST
        {
        }
        REPLY
        {
            trans1_TT_1_tdohm_100mv
        }
    }
}

COMMAND write_trans1_TT_1_tdohm_100mv
{
    BLOCK trans1_TT_1;
    INDEX 72;
    OPERATION WRITE;
    TRANSACTION
    {
        REQUEST
        {
            trans1_TT_1_tdohm_100mv
        }
        REPLY
        {
        }
    }
}

/***********************************************************************/
/*****    Menu: Specialist  **********************************************/
/***********************************************************************/

MENU Menu_Main_Specialist
{
    LABEL        [main_menu];
    ITEMS
    {
        Menu_File,
        Menu_S_Device,
        Menu_S_View,
        Menu_Options,
        Menu_Help
    }
}

/***********************************************************************/
/*****    Menu: Maintenance  *********************************************/
/***********************************************************************/

MENU Menu_Main_Maintenance
{
    LABEL        [main_menu];
    ITEMS
    {
        Menu_File,
        Menu_M_Device,
        Menu_S_View,
        Menu_Options,
        Menu_Help
    }
}

//MENU download_variables
//{
//    LABEL        [menu_load_to_PC];
//    ITEMS
//    {
//    /* PHYSICAL BLOCK    */
//        phys_st_rev,
//        phys_device_man_id,
//        phys_device_id,
//        phys_tag_desc,
//        phys_descriptor,
//        phys_message,
//        phys_install_date,
//        phys_software_rev,
//        phys_hardware_rev,
//        phys_blk_profile,
//        phys_blk_profile_rev,
//        phys_blk_dd_reference,
//        phys_blk_dd_rev,
//        phys_device_certification,
//        phys_device_ser_num,
//
//
//
//    /* TRANDSDUCER BLOCK 1    */
//        trans1_TT_1_st_rev,
//    /* TRANDSDUCER BLOCK 2    */
//        trans1_CB_1_CustomTcName,
//        trans1_CB_1_CustomTcPolyCount,
//        trans1_CB_1_CustomTcMinIn,
//        trans1_CB_1_CustomTcMinOut,
//        trans1_CB_1_CustomTcMaxOut,
//        trans1_CUSTOM_TC_POLY_1.Ohm,
//        trans1_CUSTOM_TC_POLY_1.a0,
//        trans1_CUSTOM_TC_POLY_1.a1,
//        trans1_CUSTOM_TC_POLY_1.a2,
//        trans1_CUSTOM_TC_POLY_1.a3,
//        trans1_CUSTOM_TC_POLY_1.a4
//        trans1_CUSTOM_TC_POLY_2.Ohm,
//        trans1_CUSTOM_TC_POLY_2.a0,
//        trans1_CUSTOM_TC_POLY_2.a1,
//        trans1_CUSTOM_TC_POLY_2.a2,
//        trans1_CUSTOM_TC_POLY_2.a3,
//        trans1_CUSTOM_TC_POLY_2.a4,
//        trans1_CUSTOM_TC_POLY_3.Ohm,
//        trans1_CUSTOM_TC_POLY_3.a0,
//        trans1_CUSTOM_TC_POLY_3.a1,
//        trans1_CUSTOM_TC_POLY_3.a2,
//        trans1_CUSTOM_TC_POLY_3.a3,
//        trans1_CUSTOM_TC_POLY_3.a4,
//        trans1_CUSTOM_TC_POLY_4.Ohm,
//        trans1_CUSTOM_TC_POLY_4.a0,
//        trans1_CUSTOM_TC_POLY_4.a1,
//        trans1_CUSTOM_TC_POLY_4.a2,
//        trans1_CUSTOM_TC_POLY_4.a3,
//        trans1_CUSTOM_TC_POLY_4.a4,
//        trans1_CUSTOM_TC_POLY_5.Ohm,
//        trans1_CUSTOM_TC_POLY_5.a0,
//        trans1_CUSTOM_TC_POLY_5.a1,
//        trans1_CUSTOM_TC_POLY_5.a2,
//        trans1_CUSTOM_TC_POLY_5.a3,
//        trans1_CUSTOM_TC_POLY_5.a4,
//        trans1_CB_1_CustomRtdName,
//        trans1_CB_1_CustomRtdPolyCount,
//        trans1_CB_1_CustomRtdMinIn,
//        trans1_CB_1_CustomRtdMinOut,
//        trans1_CB_1_CustomRtdMaxOut,
//        trans1_CUSTOM_RTD_POLY_1.Ohm,
//        trans1_CUSTOM_RTD_POLY_1.a0,
//        trans1_CUSTOM_RTD_POLY_1.a1,
//        trans1_CUSTOM_RTD_POLY_1.a2,
//        trans1_CUSTOM_RTD_POLY_1.a3,
//        trans1_CUSTOM_RTD_POLY_1.a4
//        trans1_CUSTOM_RTD_POLY_2.Ohm,
//        trans1_CUSTOM_RTD_POLY_2.a0,
//        trans1_CUSTOM_RTD_POLY_2.a1,
//        trans1_CUSTOM_RTD_POLY_2.a2,
//        trans1_CUSTOM_RTD_POLY_2.a3,
//        trans1_CUSTOM_RTD_POLY_2.a4,
//        trans1_CUSTOM_RTD_POLY_3.Ohm,
//        trans1_CUSTOM_RTD_POLY_3.a0,
//        trans1_CUSTOM_RTD_POLY_3.a1,
//        trans1_CUSTOM_RTD_POLY_3.a2,
//        trans1_CUSTOM_RTD_POLY_3.a3,
//        trans1_CUSTOM_RTD_POLY_3.a4,
//        trans1_CUSTOM_RTD_POLY_4.Ohm,
//        trans1_CUSTOM_RTD_POLY_4.a0,
//        trans1_CUSTOM_RTD_POLY_4.a1,
//        trans1_CUSTOM_RTD_POLY_4.a2,
//        trans1_CUSTOM_RTD_POLY_4.a3,
//        trans1_CUSTOM_RTD_POLY_4.a4,
//        trans1_CUSTOM_RTD_POLY_5.Ohm,
//        trans1_CUSTOM_RTD_POLY_5.a0,
//        trans1_CUSTOM_RTD_POLY_5.a1,
//        trans1_CUSTOM_RTD_POLY_5.a2,
//        trans1_CUSTOM_RTD_POLY_5.a3,
//        trans1_CUSTOM_RTD_POLY_5.a4,

//    /* FUNCTION BLOCK 1: AI    */
//        func1_AI_1_st_rev,
//        func1_AI_1_tag_desc,
//        func1_AI_1_batch_id,
//        func1_AI_1_batch_unit,
//        func1_AI_1_batch_operation,
//        func1_AI_1_batch_phase,
//        func1_AI_1_channel,
//        func1_AI_1_pv_ftime,
//        func1_AI_1_target_mode,
//        func1_AI_1_pv_lower_range_value,
//        func1_AI_1_pv_upper_range_value,
//        func1_AI_1_out_lower_range_value,
//        func1_AI_1_out_upper_range_value,
//        func1_AI_1_out_unit,
//        func1_AI_1_out_decimal_point,
//        func1_AI_1_hi_hi_lim,
//        func1_AI_1_hi_lim,
//        func1_AI_1_lo_lim,
//        func1_AI_1_lo_lo_lim,
//        func1_AI_1_alarm_hys,
//        func1_AI_1_FSafeType,
//        func1_AI_1_FSafeValue,
//    }
//}

MENU upload_variables
{
    LABEL        [menu_load_to_device];
    ITEMS
    {
    /* PHYSICAL BLOCK    */
        phys_tag_desc,
        phys_descriptor,
        phys_message,
        phys_install_date,
        phys_strategy,
        phys_alert_key,

    /* TRANDSDUCER BLOCK 1: */
        trans1_TT_1_tag_desc,
        trans1_TT_1_strategy,
        trans1_TT_1_alert_key,
        trans1_TT_1_lin_type,
        trans1_TT_1_bias_1,
        trans1_TT_1_primary_value_unit,
        IF (trans1_TT_1_lin_type == 0)
        {    
            trans1_TT_1_input_range,
        }
        IF ((trans1_TT_1_lin_type == 128) || (trans1_TT_1_lin_type == 131)||(trans1_TT_1_lin_type == 242) || 
            ((trans1_TT_1_lin_type >= 133) && (trans1_TT_1_lin_type <= 138)))
        {   
            trans1_TT_1_rj_type,
            trans1_TT_1_external_rj_value,
        }
//        trans1_TT_1_bias_1,
        trans1_TT_1_sensor_connection,
        trans1_TT_1_Sensor_Modify,
        trans1_TT_1_sensor_wire_check_1,
        //trans1_TT_1_Channel
        trans1_TT_1_Sensor_Modify,

        trans1_TT_1_tdohm_500r,
        trans1_TT_1_tdohm_4000r,
        trans1_TT_1_tdohm_100mv,

    /* TRANDSDUCER BLOCK 2    */
        trans1_CB_1_tag_desc,    
        trans1_CB_1_strategy,
        trans1_CB_1_alert_key,
        IF (trans1_TT_1_lin_type == 241)
        {
        trans1_CB_1_CustomRtdName,
        trans1_CB_1_CustomRtdPolyCount,
        trans1_CB_1_CustomRtdMinIn,
        trans1_CB_1_CustomRtdMinOut,
        trans1_CB_1_CustomRtdMaxOut,
        trans1_CUSTOM_RTD_POLY_1.Ohm,
        trans1_CUSTOM_RTD_POLY_1.a0,
        trans1_CUSTOM_RTD_POLY_1.a1,
        trans1_CUSTOM_RTD_POLY_1.a2,
        trans1_CUSTOM_RTD_POLY_1.a3,
        trans1_CUSTOM_RTD_POLY_1.a4,
        trans1_CUSTOM_RTD_POLY_2.Ohm,
        trans1_CUSTOM_RTD_POLY_2.a0,
        trans1_CUSTOM_RTD_POLY_2.a1,
        trans1_CUSTOM_RTD_POLY_2.a2,
        trans1_CUSTOM_RTD_POLY_2.a3,
        trans1_CUSTOM_RTD_POLY_2.a4,
        trans1_CUSTOM_RTD_POLY_3.Ohm,
        trans1_CUSTOM_RTD_POLY_3.a0,
        trans1_CUSTOM_RTD_POLY_3.a1,
        trans1_CUSTOM_RTD_POLY_3.a2,
        trans1_CUSTOM_RTD_POLY_3.a3,
        trans1_CUSTOM_RTD_POLY_3.a4,
        trans1_CUSTOM_RTD_POLY_4.Ohm,
        trans1_CUSTOM_RTD_POLY_4.a0,
        trans1_CUSTOM_RTD_POLY_4.a1,
        trans1_CUSTOM_RTD_POLY_4.a2,
        trans1_CUSTOM_RTD_POLY_4.a3,
        trans1_CUSTOM_RTD_POLY_4.a4,
        trans1_CUSTOM_RTD_POLY_5.Ohm,
        trans1_CUSTOM_RTD_POLY_5.a0,
        trans1_CUSTOM_RTD_POLY_5.a1,
        trans1_CUSTOM_RTD_POLY_5.a2,
        trans1_CUSTOM_RTD_POLY_5.a3,
        trans1_CUSTOM_RTD_POLY_5.a4,
        }
        IF (trans1_TT_1_lin_type == 242)
        {
        trans1_CB_1_CustomTcName,
        trans1_CB_1_CustomTcPolyCount,
        trans1_CB_1_CustomTcMinIn,
        trans1_CB_1_CustomTcMinOut,
        trans1_CB_1_CustomTcMaxOut,
        trans1_CUSTOM_TC_POLY_1.Ohm, 
        trans1_CUSTOM_TC_POLY_1.a0,  
        trans1_CUSTOM_TC_POLY_1.a1,  
        trans1_CUSTOM_TC_POLY_1.a2,  
        trans1_CUSTOM_TC_POLY_1.a3,  
        trans1_CUSTOM_TC_POLY_1.a4, 
        trans1_CUSTOM_TC_POLY_2.Ohm, 
        trans1_CUSTOM_TC_POLY_2.a0,  
        trans1_CUSTOM_TC_POLY_2.a1,  
        trans1_CUSTOM_TC_POLY_2.a2,  
        trans1_CUSTOM_TC_POLY_2.a3,  
        trans1_CUSTOM_TC_POLY_2.a4,  
        trans1_CUSTOM_TC_POLY_3.Ohm, 
        trans1_CUSTOM_TC_POLY_3.a0,  
        trans1_CUSTOM_TC_POLY_3.a1,  
        trans1_CUSTOM_TC_POLY_3.a2,  
        trans1_CUSTOM_TC_POLY_3.a3,  
        trans1_CUSTOM_TC_POLY_3.a4,  
        trans1_CUSTOM_TC_POLY_4.Ohm, 
        trans1_CUSTOM_TC_POLY_4.a0,  
        trans1_CUSTOM_TC_POLY_4.a1,  
        trans1_CUSTOM_TC_POLY_4.a2,  
        trans1_CUSTOM_TC_POLY_4.a3,  
        trans1_CUSTOM_TC_POLY_4.a4,  
        trans1_CUSTOM_TC_POLY_5.Ohm, 
        trans1_CUSTOM_TC_POLY_5.a0,  
        trans1_CUSTOM_TC_POLY_5.a1,  
        trans1_CUSTOM_TC_POLY_5.a2,  
        trans1_CUSTOM_TC_POLY_5.a3,  
        trans1_CUSTOM_TC_POLY_5.a4, 
        trans1_CUSTOM_TC_RJ_POLY.a0,
        trans1_CUSTOM_TC_RJ_POLY.a1,
        trans1_CUSTOM_TC_RJ_POLY.a2,
        trans1_CUSTOM_TC_RJ_POLY.a3,
        }

    /* FUNCTION BLOCK 1: AI 1    */
        func1_AI_1_tag_desc,
        func1_AI_1_strategy,
        func1_AI_1_alert_key,
        func1_AI_1_target_mode,
        func1_AI_1_batch_id,
        func1_AI_1_batch_unit,
        func1_AI_1_batch_operation,
        func1_AI_1_batch_phase,
        func1_AI_1_channel,
        func1_AI_1_lin_type,
        func1_AI_1_pv_ftime,
        func1_AI_1_pv_upper_range_value,
        func1_AI_1_pv_lower_range_value,
        func1_AI_1_out_upper_range_value,
        func1_AI_1_out_lower_range_value,
        func1_AI_1_out_unit,
        func1_AI_1_out_decimal_point,
        func1_AI_1_alarm_hys,
        func1_AI_1_hi_hi_lim,
        func1_AI_1_hi_lim,
        func1_AI_1_lo_lim,
        func1_AI_1_lo_lo_lim,
        func1_AI_1_FSafeType,
        func1_AI_1_FSafeValue,
        func1_AI_1_out_unit_text,

    /* FUNCTION BLOCK 1: AI 2    */
        func1_AI_2_tag_desc,
        func1_AI_2_strategy,
        func1_AI_2_alert_key,
        func1_AI_2_target_mode,
        func1_AI_2_batch_id,
        func1_AI_2_batch_unit,
        func1_AI_2_batch_operation,
        func1_AI_2_batch_phase,
        func1_AI_2_channel,
        func1_AI_2_lin_type,
        func1_AI_2_pv_ftime,
        func1_AI_2_pv_upper_range_value,
        func1_AI_2_pv_lower_range_value,
        func1_AI_2_out_upper_range_value,
        func1_AI_2_out_lower_range_value,
        func1_AI_2_out_unit,
        func1_AI_2_out_decimal_point,
        func1_AI_2_alarm_hys,
        func1_AI_2_hi_hi_lim,
        func1_AI_2_hi_lim,
        func1_AI_2_lo_lim,
        func1_AI_2_lo_lo_lim,
        func1_AI_2_FSafeType,
        func1_AI_2_FSafeValue,
        func1_AI_2_out_unit_text
    }
    PRE_READ_ACTIONS
    {
        method_pre_write_phys_write_locking
    }
}


/*---------------------------------------------------------------------*/
/*    Menu: Device                                                     */
/*---------------------------------------------------------------------*/

MENU Menu_S_Device
{
    LABEL        [menu_Device];
    ITEMS
    {
        std_NodeAddress,
        COLUMNBREAK,
        std_LoadinDevice,
        std_LoadinPC,
        COLUMNBREAK,
        Menu_configuration,
        COLUMNBREAK,
        Menu_cal,
        OnlineDialog_simulation_AI_1,
        OnlineDialog_simulation_AI_2,
        COLUMNBREAK,
        OnlineDialog_reset,
        OnlineDialog_write_locking,
        OnlineDialog_ident_number
    }
}

MENU Menu_M_Device
{
    LABEL        [menu_Device];
    ITEMS
    {
        std_NodeAddress,
        COLUMNBREAK,
        std_LoadinDevice,
        std_LoadinPC
    }
}

MENU Menu_configuration
{
    LABEL "Configuration";
    ITEMS
    {
        OnlineWindow_trans1_TT_1_setting,
//        OnlineWindow_trans1_CB_1_setting,
        OnlineWindow_AI_1_geral,
        OnlineWindow_AI_2_geral
    }
}

MENU OnlineWindow_trans1_TT_1_setting
{
    LABEL [trans1];
    ITEMS
    {
        Page_trans1_TT_1_Basic_Settings,
        Page_trans1_TT_1_Advanced_Settings
    }
}

MENU Page_trans1_TT_1_Basic_Settings
{
    LABEL [MC_Tab_basic];
    ITEMS
    {
        Group_trans1_TT_1_Tag,
        Group_trans1_TT_1_Sensor_Type,
        Group_trans1_TT_1_Connection_Type,
        Group_trans1_TT_1_RJ_Type,
        Group_trans1_TT_1_Sensor_Modify,
        COLUMNBREAK
    }
}
MENU Group_trans1_TT_1_Tag
{
    LABEL "Tag";
    ITEMS
    {
        trans1_TT_1_tag_desc
    }
}

MENU Group_trans1_TT_1_Sensor_Type
{
    LABEL [MC_Select_Sensor_Type];
    ITEMS
    {
        trans1_TT_1_lin_type,
        trans1_TT_1_input_range,
        trans1_TT_1_primary_value_unit (HIDDEN)
//        COLUMNBREAK,
//        method_write_trans1_TT_1_Sensor_type
    }
}

MENU Group_trans1_TT_1_Connection_Type
{
    LABEL [MC_Select_Connection_Type];
    ITEMS
    {
        trans1_TT_1_sensor_connection
//        COLUMNBREAK,
//        method_write_trans1_TT_1_sensor_connection
    }
}

MENU Group_trans1_TT_1_RJ_Type
{
    LABEL [MC_Select_RJ_Type];
    ITEMS
    {
        trans1_TT_1_rj_type,
        trans1_TT_1_external_rj_value,
        Group_trans1_TT_1_2wire_comp_pt100
//        COLUMNBREAK,
//        method_write_trans1_TT_1_rj_type
    }
        VALIDITY    IF ((trans1_TT_1_lin_type == 128) || (trans1_TT_1_lin_type == 131)||(trans1_TT_1_lin_type == 242) || 
                    ((trans1_TT_1_lin_type >= 133) && (trans1_TT_1_lin_type <= 138)))
                    {   
                            TRUE;
                        }
                        ELSE
                        {
                            FALSE;
                        }
}

MENU Group_trans1_TT_1_2wire_comp_pt100
{
    LABEL "Set 2-Wire Comp (PT100)";
    ITEMS
    {
        method_TT_1_comp_ext_pt100_two_wires_zero,
        COLUMNBREAK,
        method_TT_1_reset_ext_pt100_two_wires_zero
    }
    VALIDITY    IF (trans1_TT_1_rj_type == 3)
                {
                    TRUE;
                }
                ELSE
                {
                    FALSE;
                }
}

MENU Group_trans1_TT_1_Sensor_Modify
{
    LABEL "Modify R0 Adjust";
    ITEMS
    {
        trans1_TT_1_Sensor_Modify
//        COLUMNBREAK,
//        method_write_trans1_TT_1_Sensor_Modify
    }
}

MENU Page_trans1_TT_1_Advanced_Settings
{
    LABEL [MC_Tab_advanced];
    ITEMS
    {
        trans1_TT_1_lin_type (HIDDEN),
        trans1_TT_1_input_range (HIDDEN),
        Group_trans1_TT_1_primary_value_unit,
        Group_trans1_TT_1_bias_of_channel,
        Group_trans1_TT_1_2wire_compensation,
        Group_trans1_TT_1_sensor_wire_check,
        Group_trans1_TT_1_sensor_limit,      
        COLUMNBREAK
    }
}

MENU Group_trans1_TT_1_sensor_wire_check
{
    LABEL [MC_Set_Sensor_Wire_Check];
    ITEMS
    {
        trans1_TT_1_sensor_wire_check_1
//        COLUMNBREAK,
//        method_write_trans1_TT_1_sensor_wire_check_1
    }
}

MENU Group_trans1_TT_1_primary_value_unit
{
    LABEL [MC_Select_Output_Unit];
    ITEMS
    {
        trans1_TT_1_primary_value_unit
//        COLUMNBREAK,
//        method_write_trans1_TT_1_primary_value_unit
    }
}

MENU Group_trans1_TT_1_bias_of_channel
{
    LABEL [MC_Set_Bias_of_Channel];
    ITEMS
    {
        trans1_TT_1_bias_1
//        COLUMNBREAK,
//        method_write_trans1_TT_1_bias_1
    }
}

MENU Group_trans1_TT_1_2wire_compensation
{
    LABEL [MC_Set_2Wire_Comp];
    ITEMS
    {
//        trans1_TT_1_Channel,
//        COLUMNBREAK,
        method_set_trans1_TT_1_two_Wires_Comp,
        method_reset_trans1_TT_1_two_Wires_Comp
    }
    VALIDITY    IF (((trans1_TT_1_lin_type == 102) || (trans1_TT_1_lin_type == 105) ||
                    (trans1_TT_1_lin_type == 240) || (trans1_TT_1_lin_type == 127) ||
                    (trans1_TT_1_lin_type == 241) ||
                    ((trans1_TT_1_lin_type == 0) && (trans1_TT_1_input_range == 128 || trans1_TT_1_input_range == 129)))&&(trans1_TT_1_sensor_connection==0 ))
                
                {
                    TRUE;
                }
                ELSE
                {
                    FALSE;
                }
}

MENU Group_trans1_TT_1_sensor_limit
{
    LABEL [MC_Sensor_Limits];
    ITEMS
    {
        trans1_TT_1_lower_sensor_limit,
        trans1_TT_1_upper_sensor_limit
    }
}

MENU Page_trans1_TT_1_Factory_Calibration
{
    LABEL "Factory Calibration";
    ITEMS
    {
        Group_trans1_TT_1_rtd_calibration,
        Group_trans1_TT_1_tc_calibration,
        COLUMNBREAK
    }
}

MENU Group_trans1_TT_1_rtd_calibration
{
    LABEL "RTD Factory Calibration";
    ITEMS
    {
        trans1_TT_1_tdohm_500r,
        trans1_TT_1_tdohm_4000r, 
        method_TT_1_rtd_calibration
//        method_TT_1_rtd_normal_comp,
//        method_TT_1_rtd_high_comp,
//        method_TT_1_rtd_low_comp
    }
}

MENU Group_trans1_TT_1_tc_calibration
{
    LABEL "TC Factory Calibration";
    ITEMS
    {
        method_TT_1_TC_full_comp,
        trans1_TT_1_tdohm_100mv,
        method_TT_1_TC_calibration
    }

}

MENU Menu_cal
{
    LABEL        [MC_menu_cal];
    ITEMS
    {
        OnlineDialog_trans1_TT_1_Factory_Calibration,
        OnlineDialog_trans1_TT_1_cal,
        OnlineDialog_trans1_CB_1_table
    }
}

MENU OnlineDialog_trans1_TT_1_Factory_Calibration
{
    LABEL        "Factory Calibration";
    ITEMS
    {
        Page_trans1_TT_1_Factory_Calibration
    }
}

MENU OnlineDialog_trans1_TT_1_cal
{
    LABEL        [MC_cal_trd1];
    ITEMS
    {
        Page_trans1_TT_1_cal_para,
        Page_trans1_TT_1_cal_lo_point,
        Page_trans1_TT_1_cal_hi_point
    }
}

MENU Page_trans1_TT_1_cal_para
{
    LABEL     [MC_cal_para];
    ITEMS
    {
        trans1_TT_1_Cal_Unit,
        trans1_TT_1_lin_type,
        trans1_TT_1_input_range,
        COLUMNBREAK//,
//        method_set
    }
}

MENU Page_trans1_TT_1_cal_lo_point
{
    LABEL     [MC_cal_lo_point];
    ITEMS
    {
        trans1_TT_1_lower_sensor_limit (READ_ONLY),
        trans1_TT_1_Cal_Point_Lo (READ_ONLY),
        trans1_TT_1_Sensor_Value_1,
        COLUMNBREAK,
        method_set_trans1_TT_1_cal_point_lo
    }
}

MENU Page_trans1_TT_1_cal_hi_point
{
    LABEL     [MC_cal_hi_point];
    ITEMS
    {
        trans1_TT_1_upper_sensor_limit (READ_ONLY),
        trans1_TT_1_Cal_Point_Hi (READ_ONLY),
        trans1_TT_1_Sensor_Value_1,
        COLUMNBREAK,
        method_set_trans1_TT_1_cal_point_hi
    }
}

/*---------------------------------------------------------------------*/
/*    Menu: View                                                       */
/*---------------------------------------------------------------------*/
MENU Menu_S_View
{
    LABEL        [menu_View];
    ITEMS
    {
        OnlineWindow_display,
        COLUMNBREAK,
        OnlineWindow_yt,
        Menu_S_alarm,
        OnlineWindow_diagnosis,
        COLUMNBREAK,
        std_Funktionsleiste,
        std_Statuszeile,
        COLUMNBREAK,
        std_Update
    }
}

MENU OnlineWindow_display
{
    LABEL        [menu_dialog_display];
    ITEMS
    {
        Page_display_trans1_TT_1,
        Page_display_func1_AI_1,
        Page_display_func1_AI_2
    }
}

MENU Page_display_trans1_TT_1
{
    LABEL        "Transducer 1";
    ITEMS
    {
        BarVal_trans1_TT_1_display_measure,
        Group_trans1_TT_1_display_Primary_Value,
        Group_trans1_TT_1_display_Secondary_Value,
        trans1_TT_1_primary_value_unit (HIDDEN)
    }
}

MENU BarVal_trans1_TT_1_display_measure
{
    LABEL        [menu_dialog_display_measure];
    ITEMS
    {
        trans1_TT_1_primary_value,
        trans1_TT_1_lower_sensor_limit,
        trans1_TT_1_upper_sensor_limit
    }
}

MENU Group_trans1_TT_1_display_Primary_Value
{
    LABEL        [MC_Primary_Value];
    ITEMS
    {
        trans1_TT_1_primary_value,
        COLUMNBREAK,
        trans1_TT_1_primary_value_status_quality,
        trans1_TT_1_primary_value_status_limit
    }
}

MENU Group_trans1_TT_1_display_Secondary_Value
{
    LABEL        [MC_Secondary_Value];
    ITEMS
    {
        trans1_TT_1_secondary_value_1,
        COLUMNBREAK,
        trans1_TT_1_input_fault_gen,
        trans1_TT_1_input_fault_1,
        trans1_TT_1_rj_temp,
        trans1_TT_1_external_rj_value                     (READ_ONLY),
        trans1_TT_1_rj_type                               (READ_ONLY)
    }
}

MENU Menu_S_alarm
{
    LABEL        [menu_dialog_alarm];
    ITEMS
    {
        OnlineWindow_S_alarm_func1_AI_1,
        OnlineWindow_S_alarm_func1_AI_2
    }
}

MENU OnlineWindow_diagnosis
{
    LABEL        [menu_dialog_diagnosis];
    ITEMS
    {
        Page_diagnosis_general,
        Page_diagnosis_phys_block,
        Page_diagnosis_trans1_TT_1_block,
        Page_diagnosis_func1_AI_1,
        Page_diagnosis_func1_AI_2
    }
}

MENU Page_diagnosis_trans1_TT_1_block
{
    LABEL        [trans1_block];
    ITEMS
    {
        trans1_TT_1_blk_object,
        trans1_TT_1_blk_parent_class,
        trans1_TT_1_blk_class,
 //       trans1_TT_1_blk_dd_reference,
        trans1_TT_1_blk_devrev,
        trans1_TT_1_blk_devrevcomp,  
        trans1_TT_1_blk_dd_rev,
        trans1_TT_1_blk_profile,
        trans1_TT_1_blk_profile_rev,
        trans1_TT_1_st_rev,
        trans1_TT_1_actual_mode
    }
}

/***********************************************************************/
/*****    Table: Specialist    *****************************************/
/***********************************************************************/

MENU Table_Main_Specialist
{
    LABEL    [MC_Table_Main_Specialist_TT106];
    ITEMS
    {
        Tab_s_info,
        Tab_s_trd,
        Tab_s_AI_1,
        Tab_s_AI_2
    }
}

MENU Tab_s_info
{
    LABEL    [MC_Tab_info];
    ITEMS
    {
        Tab_s_manuf_info,       /* file Phys_Blk.inc */
        Tab_s_block_tag,
        Tab_s_get_info,         /* file Phys_Blk.inc */
        Tab_serial_numbers,
        Tab_device_revisions,   /* file Phys_Blk.inc */
        Tab_s_certificates      /* file Phys_Blk.inc */
    }
}

MENU Tab_s_block_tag
{
    LABEL    [MC_Tab_block_tag];
    ITEMS
    {
        phys_tag_desc,
        trans1_TT_1_tag_desc,
        func1_AI_1_tag_desc,
        func1_AI_2_tag_desc
    }
}

MENU Tab_serial_numbers
{
    LABEL   [MC_Tab_serial_numbers];
    ITEMS
    {
        phys_device_ser_num   (READ_ONLY)
    }
}

MENU Tab_s_trd
{
    LABEL   [trans1];
    ITEMS
    {
        trans1_TT_1_st_rev,
        trans1_TT_1_lin_type,
        IF (trans1_TT_1_lin_type==0)
        { trans1_TT_1_input_range,}
        trans1_TT_1_primary_value_unit,
        IF ( (trans1_TT_1_lin_type == 102 || trans1_TT_1_lin_type == 105 || trans1_TT_1_lin_type == 240 || trans1_TT_1_lin_type == 127) || \
             (trans1_TT_1_lin_type == 241) || (trans1_TT_1_lin_type == 0  && (trans1_TT_1_input_range == 128 || trans1_TT_1_input_range == 129)))
        { trans1_TT_1_sensor_connection, }
        IF ((trans1_TT_1_lin_type == 128) || (trans1_TT_1_lin_type == 131)||(trans1_TT_1_lin_type == 242) || 
            ((trans1_TT_1_lin_type >= 133) && (trans1_TT_1_lin_type <= 138)))
        {
            trans1_TT_1_rj_type,
            IF (trans1_TT_1_rj_type == 2)
            {trans1_TT_1_external_rj_value,}
        }
        trans1_TT_1_bias_1,
        trans1_TT_1_Sensor_Modify,
        trans1_TT_1_sensor_wire_check_1,
        trans1_TT_1_lower_sensor_limit,
        trans1_TT_1_upper_sensor_limit,

        IF (trans1_TT_1_lin_type == 242)
        {
            Tab_custom_tc
        }

        IF (trans1_TT_1_lin_type == 241)
        {
            Tab_custom_rtd
        }
    }
}

MENU Tab_custom_tc
{
    LABEL    "Linearization Sensor TC";
    ACCESS  OFFLINE;
    ITEMS
    {
        Tab_settings_tc,
    }
}
MENU Tab_settings_tc
{
    LABEL    "Settings";
    ACCESS  OFFLINE;
    ITEMS
    {
        trans1_CB_1_CustomTcName,
        trans1_CB_1_CustomTcPolyCount,
        Tab_our_tc
    }
}

MENU Tab_our_tc
{
    LABEL    "Output Range";
    ACCESS  OFFLINE;
    ITEMS
    {
        trans1_CB_1_CustomTcMinOut,
        trans1_CB_1_CustomTcMaxOut,
        IF ((trans1_TT_1_lin_type == 242) && (trans1_CB_1_CustomTcPolyCount >= 1))
        {
            Tab_TC_Poly1,
        }
        IF ((trans1_TT_1_lin_type == 242) && (trans1_CB_1_CustomTcPolyCount >= 2))
        {
            Tab_TC_Poly2,
        }
        IF ((trans1_TT_1_lin_type == 242) && (trans1_CB_1_CustomTcPolyCount >= 3))
        {
            Tab_TC_Poly3,
        }
        IF ((trans1_TT_1_lin_type == 242) && (trans1_CB_1_CustomTcPolyCount >= 4))
        {
            Tab_TC_Poly4,
        }
        IF ((trans1_TT_1_lin_type == 242) && (trans1_CB_1_CustomTcPolyCount >= 5))
        {
            Tab_TC_Poly5,
        }
        IF ((trans1_TT_1_lin_type == 242) && (trans1_CB_1_CustomTcPolyCount >= 1))
        {
            Tab_TC_RJ_Poly
        }
    }
}

/**** CUSTOM|TC|POLY RJ****/
MENU Tab_TC_RJ_Poly
{
    LABEL    "Polynomial Coefficients - Reference Junction";
    ACCESS   OFFLINE;
    ITEMS
    {
        trans1_CUSTOM_TC_RJ_POLY.a0,
        trans1_CUSTOM_TC_RJ_POLY.a1,
        trans1_CUSTOM_TC_RJ_POLY.a2,
        trans1_CUSTOM_TC_RJ_POLY.a3
    }
}

/**** CUSTOM|TC|POLY1 ****/
MENU Tab_TC_Poly1
{
    LABEL   "Polynomial Coefficients - Section 1";
    ACCESS  OFFLINE;
    ITEMS
    {
        trans1_CB_1_CustomTcMinIn,
        trans1_CUSTOM_TC_POLY_1.Ohm,
        trans1_CUSTOM_TC_POLY_1.a0,
        trans1_CUSTOM_TC_POLY_1.a1,
        trans1_CUSTOM_TC_POLY_1.a2,
        trans1_CUSTOM_TC_POLY_1.a3,
        trans1_CUSTOM_TC_POLY_1.a4
    }
}

/**** CUSTOM|TC|POLY2 ****/
MENU Tab_TC_Poly2
{
    LABEL   "Polynomial Coefficients - Section 2";
    ACCESS  OFFLINE;
    ITEMS
    {
        MinIn_CB_1_CustomTc_Poly_2,
        trans1_CUSTOM_TC_POLY_2.Ohm,
        trans1_CUSTOM_TC_POLY_2.a0,
        trans1_CUSTOM_TC_POLY_2.a1,
        trans1_CUSTOM_TC_POLY_2.a2,
        trans1_CUSTOM_TC_POLY_2.a3,
        trans1_CUSTOM_TC_POLY_2.a4
    }
}

/**** CUSTOM|TC|POLY3 ****/
MENU Tab_TC_Poly3
{
    LABEL   "Polynomial Coefficients - Section 3";
    ACCESS  OFFLINE;
    ITEMS
    {
        MinIn_CB_1_CustomTc_Poly_3,
        trans1_CUSTOM_TC_POLY_3.Ohm,
        trans1_CUSTOM_TC_POLY_3.a0,
        trans1_CUSTOM_TC_POLY_3.a1,
        trans1_CUSTOM_TC_POLY_3.a2,
        trans1_CUSTOM_TC_POLY_3.a3,
        trans1_CUSTOM_TC_POLY_3.a4
    }
}

/**** CUSTOM|TC|POLY1 ****/
MENU Tab_TC_Poly4
{
    LABEL   "Polynomial Coefficients - Section 4";
    ACCESS  OFFLINE;
    ITEMS
    {
        MinIn_CB_1_CustomTc_Poly_4,
        trans1_CUSTOM_TC_POLY_4.Ohm,
        trans1_CUSTOM_TC_POLY_4.a0,
        trans1_CUSTOM_TC_POLY_4.a1,
        trans1_CUSTOM_TC_POLY_4.a2,
        trans1_CUSTOM_TC_POLY_4.a3,
        trans1_CUSTOM_TC_POLY_4.a4
    }
}

/**** CUSTOM|TC|POLY1 ****/
MENU Tab_TC_Poly5
{
    LABEL   "Polynomial Coefficients - Section 5";
    ACCESS  OFFLINE;
    ITEMS
    {
        MinIn_CB_1_CustomTc_Poly_5,
        trans1_CUSTOM_TC_POLY_5.Ohm,
        trans1_CUSTOM_TC_POLY_5.a0,
        trans1_CUSTOM_TC_POLY_5.a1,
        trans1_CUSTOM_TC_POLY_5.a2,
        trans1_CUSTOM_TC_POLY_5.a3,
        trans1_CUSTOM_TC_POLY_5.a4
    }
}

MENU Tab_custom_rtd
{
    LABEL    "Linearization Sensor RTD";
    ACCESS  OFFLINE;
    ITEMS
    {
        Tab_settings_rtd,
    }
}

MENU Tab_settings_rtd
{
    LABEL    "Settings";
    ACCESS  OFFLINE;
    ITEMS
    {
        trans1_CB_1_CustomRtdName,
        trans1_CB_1_CustomRtdPolyCount,
        Tab_our_rtd
    }
}

MENU Tab_our_rtd
{
    LABEL    "Output Range";
    ACCESS  OFFLINE;
    ITEMS
    {
        trans1_CB_1_CustomRtdMinOut,
        trans1_CB_1_CustomRtdMaxOut,
        IF ((trans1_TT_1_lin_type == 241) && (trans1_CB_1_CustomRtdPolyCount >= 1))
        {
            Tab_RTD_Poly1,
        }
        IF ((trans1_TT_1_lin_type == 241) && (trans1_CB_1_CustomRtdPolyCount >= 2))
        {
            Tab_RTD_Poly2,
        }
        IF ((trans1_TT_1_lin_type == 241) && (trans1_CB_1_CustomRtdPolyCount >= 3))
        {
            Tab_RTD_Poly3,
        }
        IF ((trans1_TT_1_lin_type == 241) && (trans1_CB_1_CustomRtdPolyCount >= 4))
        {
            Tab_RTD_Poly4,
        }
        IF ((trans1_TT_1_lin_type == 241) && (trans1_CB_1_CustomRtdPolyCount >= 5))
        {
            Tab_RTD_Poly5
        }
    }
}

/**** CUSTOM|RTD|POLY1 ****/
MENU Tab_RTD_Poly1
{
    LABEL   "Polynomial Coefficients - Section 1";
    ACCESS  OFFLINE;
    ITEMS
    {
        trans1_CB_1_CustomRtdMinIn,
        trans1_CUSTOM_RTD_POLY_1.Ohm,
        trans1_CUSTOM_RTD_POLY_1.a0,
        trans1_CUSTOM_RTD_POLY_1.a1,
        trans1_CUSTOM_RTD_POLY_1.a2,
        trans1_CUSTOM_RTD_POLY_1.a3,
        trans1_CUSTOM_RTD_POLY_1.a4
    }
}

/**** CUSTOM|RTD|POLY2 ****/
MENU Tab_RTD_Poly2
{
    LABEL   "Polynomial Coefficients - Section 2";
    ACCESS  OFFLINE;
    ITEMS
    {
        MinIn_CB_1_CustomRtd_Poly_2,
        trans1_CUSTOM_RTD_POLY_2.Ohm,
        trans1_CUSTOM_RTD_POLY_2.a0,
        trans1_CUSTOM_RTD_POLY_2.a1,
        trans1_CUSTOM_RTD_POLY_2.a2,
        trans1_CUSTOM_RTD_POLY_2.a3,
        trans1_CUSTOM_RTD_POLY_2.a4
    }
}

/**** CUSTOM|RTD|POLY3 ****/
MENU Tab_RTD_Poly3
{
    LABEL   "Polynomial Coefficients - Section 3";
    ACCESS  OFFLINE;
    ITEMS
    {
        MinIn_CB_1_CustomRtd_Poly_3,
        trans1_CUSTOM_RTD_POLY_3.Ohm,
        trans1_CUSTOM_RTD_POLY_3.a0,
        trans1_CUSTOM_RTD_POLY_3.a1,
        trans1_CUSTOM_RTD_POLY_3.a2,
        trans1_CUSTOM_RTD_POLY_3.a3,
        trans1_CUSTOM_RTD_POLY_3.a4
    }
}

/**** CUSTOM|RTD|POLY4 ****/
MENU Tab_RTD_Poly4
{
    LABEL   "Polynomial Coefficients - Section 4";
    ACCESS  OFFLINE;
    ITEMS
    {
        MinIn_CB_1_CustomRtd_Poly_4,
        trans1_CUSTOM_RTD_POLY_4.Ohm,
        trans1_CUSTOM_RTD_POLY_4.a0,
        trans1_CUSTOM_RTD_POLY_4.a1,
        trans1_CUSTOM_RTD_POLY_4.a2,
        trans1_CUSTOM_RTD_POLY_4.a3,
        trans1_CUSTOM_RTD_POLY_4.a4
    }
}

/**** CUSTOM|RTD|POLY1 ****/
MENU Tab_RTD_Poly5
{
    LABEL   "Polynomial Coefficients - Section 5";
    ACCESS  OFFLINE;
    ITEMS
    {
        MinIn_CB_1_CustomRtd_Poly_5,
        trans1_CUSTOM_RTD_POLY_5.Ohm,
        trans1_CUSTOM_RTD_POLY_5.a0,
        trans1_CUSTOM_RTD_POLY_5.a1,
        trans1_CUSTOM_RTD_POLY_5.a2,
        trans1_CUSTOM_RTD_POLY_5.a3,
        trans1_CUSTOM_RTD_POLY_5.a4
    }
}

/******************************************************************************/
/*****    Table: Maintenance    ***********************************************/
/******************************************************************************/
MENU Table_Main_Maintenance
{
    LABEL    [MC_Table_Main_Maintenance_TT106];
    ITEMS
    {
        Tab_m_info,
        Tab_m_trd,
        Tab_m_AI_1,
        Tab_m_AI_2
    }
}

MENU Tab_m_info
{
    LABEL    [MC_Tab_info];
    ITEMS
    {
        Tab_m_manuf_info,       /* file Phys_Blk.inc */
        Tab_m_block_tag,
        Tab_m_get_info,         /* file Phys_Blk.inc */
        Tab_serial_numbers,     /* file Phys_Blk.inc */
        Tab_device_revisions,   /* file Phys_Blk.inc */
        Tab_m_certificates      /* file Phys_Blk.inc */
    }
}

MENU Tab_m_block_tag
{
    LABEL    [MC_Tab_block_tag];
    ITEMS
    {
        phys_tag_desc  (READ_ONLY),
        trans1_TT_1_tag_desc  (READ_ONLY),
        func1_AI_1_tag_desc  (READ_ONLY),
        func1_AI_2_tag_desc  (READ_ONLY)
    }
}

MENU Tab_m_trd
{
    LABEL   [trans1];
    ITEMS
    {
        trans1_TT_1_st_rev,
        trans1_TT_1_lin_type  (READ_ONLY),
        trans1_TT_1_input_range  (READ_ONLY),
        trans1_TT_1_primary_value_unit  (READ_ONLY),
        trans1_TT_1_sensor_connection  (READ_ONLY),
        trans1_TT_1_rj_type  (READ_ONLY),
        trans1_TT_1_external_rj_value  (READ_ONLY),
        trans1_TT_1_bias_1  (READ_ONLY),
        trans1_TT_1_Sensor_Modify  (READ_ONLY),
        trans1_TT_1_sensor_wire_check_1 (READ_ONLY),
        trans1_TT_1_lower_sensor_limit  (READ_ONLY),
        trans1_TT_1_upper_sensor_limit  (READ_ONLY)
    }
}

METHOD std_NodeAddress
{
    LABEL        [menu_Device_NodeAddress];
    DEFINITION
    {
    }
}

METHOD std_LoadinDevice
{
    LABEL        [menu_Device_LoadinDevice];
    DEFINITION
    {
    }
}

METHOD std_LoadinPC
{
    LABEL        [menu_Device_LoadinPC];
    DEFINITION
    {
    }
}

METHOD std_Funktionsleiste
{
    LABEL        [menu_View_Toolbar];
    DEFINITION
    {
    }
}

METHOD std_Statuszeile
{
    LABEL        [menu_View_Statusbar];
    DEFINITION
    {
    }
}

METHOD std_Update
{
    LABEL        [menu_View_Update];
    DEFINITION
    {
    }
}

METHOD method_set
{
    LABEL        [MC_Write];
    HELP         [transfer_help];
    DEFINITION
    {
    }
}

METHOD method_post_write_read_device_values
{
    LABEL  "";
    DEFINITION
    {
        DELAY_TIME(1);
        ReadCommand(read_trans1_TT_1_bias_1);
        ReadCommand(read_trans1_TT_1_upper_sensor_limit);
        ReadCommand(read_trans1_TT_1_lower_sensor_limit);
    }
}

METHOD method_tt_1_lin_type
{
    LABEL        [MC_method_tt_lin_type];
    DEFINITION
    {
        switch (trans1_TT_1_lin_type)
        {
        case 0:
            switch (trans1_TT_1_input_range)
            {
            case 0:
                if (trans1_TT_1_primary_value_unit != 1243)
                {
                    trans1_TT_1_primary_value_unit = 1243;
                }
                trans1_TT_1_upper_sensor_limit = 100;
                trans1_TT_1_lower_sensor_limit = -100;
                break;

            case 128:
                if ((trans1_TT_1_primary_value_unit != 1281) || (trans1_TT_1_primary_value_unit != 1284))
                {
                    trans1_TT_1_primary_value_unit = 1281;
                }
                trans1_TT_1_upper_sensor_limit = 500;
                trans1_TT_1_lower_sensor_limit = 0;
                break;

            case 129:
                if ((trans1_TT_1_primary_value_unit != 1281) || (trans1_TT_1_primary_value_unit != 1284))
                {
                    trans1_TT_1_primary_value_unit = 1281;
                }
                trans1_TT_1_upper_sensor_limit = 4000;
                trans1_TT_1_lower_sensor_limit = 0;
                break;
            }
            break;

        case 102:
        case 105:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 850;
            trans1_TT_1_lower_sensor_limit = -200;
            break;

        case 240:
        case 127:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 150;
            trans1_TT_1_lower_sensor_limit = -50;
            break;

        case 128:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1820;
            trans1_TT_1_lower_sensor_limit = 0;
            break;

        case 131:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1000;
            trans1_TT_1_lower_sensor_limit = -270;
            break;

        case 133:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1200;
            trans1_TT_1_lower_sensor_limit = -210;
            break;

        case 134:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1372;
            trans1_TT_1_lower_sensor_limit = -270;
            break;

        case 135:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1300;
            trans1_TT_1_lower_sensor_limit = -270;
            break;

        case 136:
        case 137:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1768;
            trans1_TT_1_lower_sensor_limit = -50;
            break;

        case 138:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 400;
            trans1_TT_1_lower_sensor_limit = -270;
            break;

        case 241:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 850;
            trans1_TT_1_lower_sensor_limit = -200;
            break;

        case 242:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1768;
            trans1_TT_1_lower_sensor_limit = -270;
            break;
        }

        switch (trans1_TT_1_primary_value_unit)
        {
        case 1000:  //K ¶
            trans1_TT_1_upper_sensor_limit += 273.15;
            trans1_TT_1_lower_sensor_limit += 273.15;
            break;

        case 1001:  //C ¶
        case 1243:  //mV
        case 1281:  //Ohm
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit;
            break;

        case 1002:  //F ¶
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit*9/5+32;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit*9/5+32;
            break;

        case 1003:  //R ¶
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit*9/5+32+495.69;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit*9/5+32+495.69;
            break;

        case 1284:  //kOhm
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit/1000;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit/1000;
           break;
        }

//        WriteCommand(write_trans1_TT_1_primary_value_unit);
//        ReadCommand(read_trans1_TT_1_primary_value_unit);
//        ReadCommand(read_trans1_TT_1_upper_sensor_limit);
//        ReadCommand(read_trans1_TT_1_lower_sensor_limit);
    }
}

METHOD method_tt_1_input_range
{
    LABEL        [MC_method_tt_input_range];
    DEFINITION
    {
        if (trans1_TT_1_lin_type == 0)
        {
            switch (trans1_TT_1_input_range)
            {
            case 0:
                if (trans1_TT_1_primary_value_unit != 1243)
                {
                    trans1_TT_1_primary_value_unit = 1243;
                }
                trans1_TT_1_upper_sensor_limit = 100;
                trans1_TT_1_lower_sensor_limit = -100;
                break;

            case 128:
                if ((trans1_TT_1_primary_value_unit != 1281) || (trans1_TT_1_primary_value_unit != 1284))
                {
                    trans1_TT_1_primary_value_unit = 1281;
                }
                trans1_TT_1_upper_sensor_limit = 500;
                trans1_TT_1_lower_sensor_limit = 0;
                break;

            case 129:
                if ((trans1_TT_1_primary_value_unit != 1281) || (trans1_TT_1_primary_value_unit != 1284))
                {
                    trans1_TT_1_primary_value_unit = 1281;
                }
                trans1_TT_1_upper_sensor_limit = 4000;
                trans1_TT_1_lower_sensor_limit = 0;
                break;
            }
        }

//        WriteCommand(write_trans1_TT_1_primary_value_unit);
//        ReadCommand(read_trans1_TT_1_primary_value_unit);
//        ReadCommand(read_trans1_TT_1_upper_sensor_limit);
//        ReadCommand(read_trans1_TT_1_lower_sensor_limit);
    }
}

METHOD method_pre_write_phys_write_locking
{
    LABEL   [method_pre_write_phys_write_locking];
    DEFINITION
    {
        int ret;
        ReadCommand (read_phys_write_locking);
        if ( phys_write_locking == 0 )
        {
            ret = ACKNOWLEDGE([label_DeviceIsWriteProtected]);
            if (ret) process_abort();
        }
    }
}

METHOD method_write_trans1_TT_1_Sensor_type
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_lin_type);
        ReadCommand(read_trans1_TT_1_lin_type);

        if (trans1_TT_1_lin_type == 0)
        {
            WriteCommand(write_trans1_TT_1_input_range);
            ReadCommand(read_trans1_TT_1_input_range);
        }

        switch (trans1_TT_1_lin_type)
        {
        case 0:
            switch (trans1_TT_1_input_range)
            {
            case 0:
                trans1_TT_1_primary_value_unit = 1243;
                trans1_TT_1_upper_sensor_limit = 100;
                trans1_TT_1_lower_sensor_limit = -100;
                break;

            case 128:
                trans1_TT_1_primary_value_unit = 1281;
                trans1_TT_1_upper_sensor_limit = 500;
                trans1_TT_1_lower_sensor_limit = 0;
                break;

            case 129:
                trans1_TT_1_primary_value_unit = 1281;
                trans1_TT_1_upper_sensor_limit = 4000;
                trans1_TT_1_lower_sensor_limit = 0;
                break;
            }
            break;

        case 102:
        case 105:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 850;
            trans1_TT_1_lower_sensor_limit = -200;
            break;

        case 240:
        case 127:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 150;
            trans1_TT_1_lower_sensor_limit = -50;
            break;

        case 128:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1820;
            trans1_TT_1_lower_sensor_limit = 0;
            break;

        case 131:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1000;
            trans1_TT_1_lower_sensor_limit = -270;
            break;

        case 133:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1200;
            trans1_TT_1_lower_sensor_limit = -210;
            break;

        case 134:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1372;
            trans1_TT_1_lower_sensor_limit = -270;
            break;

        case 135:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1300;
            trans1_TT_1_lower_sensor_limit = -270;
            break;

        case 136:
        case 137:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1768;
            trans1_TT_1_lower_sensor_limit = -50;
            break;

        case 138:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 400;
            trans1_TT_1_lower_sensor_limit = -270;
            break;

        case 241:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 850;
            trans1_TT_1_lower_sensor_limit = -200;
            break;

        case 242:
            if ((trans1_TT_1_primary_value_unit == 1243) || (trans1_TT_1_primary_value_unit == 1281) || (trans1_TT_1_primary_value_unit == 1284))
            {
                trans1_TT_1_primary_value_unit = 1001;
            }
            trans1_TT_1_upper_sensor_limit = 1768;
            trans1_TT_1_lower_sensor_limit = -270;
            break;
        }

        switch (trans1_TT_1_primary_value_unit)
        {
        case 1000:  //K ¶
            trans1_TT_1_upper_sensor_limit += 273.15;
            trans1_TT_1_lower_sensor_limit += 273.15;
            break;

        case 1001:  //C ¶
        case 1243:  //mV
        case 1281:  //Ohm
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit;
            break;

        case 1002:  //F ¶
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit*9/5+32;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit*9/5+32;
            break;

        case 1003:  //R ¶
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit*9/5+32+495.69;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit*9/5+32+495.69;
            break;

        case 1284:  //kOhm
            trans1_TT_1_upper_sensor_limit = trans1_TT_1_upper_sensor_limit/1000;
            trans1_TT_1_lower_sensor_limit = trans1_TT_1_lower_sensor_limit/1000;
           break;
        }

        WriteCommand(write_trans1_TT_1_primary_value_unit);

        ReadCommand(read_trans1_TT_1_primary_value_unit);
        ReadCommand(read_trans1_TT_1_upper_sensor_limit);
        ReadCommand(read_trans1_TT_1_lower_sensor_limit);
    }
}

//METHOD method_write_trans1_TT_1_input_range
//{
//    LABEL [MC_Write];
//    DEFINITION
//    {
//        WriteCommand(write_trans1_TT_1_input_range);
//        ReadCommand(read_trans1_TT_1_input_range);
//    }
//    VALIDITY    IF (trans1_TT_1_lin_type == 0)
//                {
//                    TRUE;
//                }
//                ELSE
//                {
//                    FALSE;
//                }
//}

METHOD method_write_trans1_TT_1_sensor_connection
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_sensor_connection);
        ReadCommand(read_trans1_TT_1_sensor_connection);
    }
}

METHOD method_write_trans1_TT_1_rj_type
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_rj_type);
        ReadCommand(read_trans1_TT_1_rj_type);
    }
}

METHOD method_write_trans1_TT_1_Sensor_Modify
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_Sensor_Modify);
        ReadCommand(read_trans1_TT_1_Sensor_Modify);
    }
}
METHOD method_write_trans1_TT_1_primary_value_unit
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_primary_value_unit);
        ReadCommand(read_trans1_TT_1_primary_value_unit);
    }
}

METHOD method_write_trans1_TT_1_bias_1
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_bias_1);
        ReadCommand(read_trans1_TT_1_bias_1);
    }
}

METHOD method_write_trans1_TT_1_sensor_wire_check_1
{
    LABEL [MC_Write];
    DEFINITION
    {
        WriteCommand(write_trans1_TT_1_sensor_wire_check_1);
        ReadCommand(read_trans1_TT_1_sensor_wire_check_1);
    }
}

METHOD method_set_trans1_TT_1_two_Wires_Comp
{
    LABEL        [MC_Write];
    DEFINITION
    {
        int fValue;
        //ReadCommand(func1_AI_simulation_enabled);
        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            //WriteCommand (write_trans1_TT_1_Channel);
            trans1_TT_1_Two_Wires_Comp = 1;
            WriteCommand (write_trans1_TT_1_Two_Wires_Comp);
            fValue = 1;
            while(fValue = 0)
            {
                ReadCommand (read_trans1_TT_1_Two_Wires_Comp);
                fValue = ivar_value(trans1_TT_1_Two_Wires_Comp);
            }
            if (fValue == 0) PUT_MESSAGE("Finished.");
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");
        }
    }
}

METHOD method_reset_trans1_TT_1_two_Wires_Comp
{
    LABEL "Reset";
    DEFINITION
    {
        int iValue;

        phys_factory_reset = 32770;
        WriteCommand(write_phys_factory_reset);
        iValue = 1;
        while(iValue == 1)
        {
            ReadCommand (read_phys_factory_reset);
            iValue = ivar_value(phys_factory_reset);
        }
        if (iValue == 0) PUT_MESSAGE("Finished.");
    }
}

METHOD method_TT_1_comp_ext_pt100_two_wires_zero
{
    LABEL [MC_Write];
    DEFINITION
    {
        int fValue;
        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            trans1_TT_1_Two_Wires_Comp = 8;
            WriteCommand(write_trans1_TT_1_Two_Wires_Comp);
            fValue = 1;
            while(fValue = 0)
            {
                ReadCommand (read_trans1_TT_1_Two_Wires_Comp);
                fValue = ivar_value(trans1_TT_1_Two_Wires_Comp);
            }
            if (fValue == 0) PUT_MESSAGE("Finished.");
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");
        }
    }
}

METHOD method_TT_1_reset_ext_pt100_two_wires_zero
{
    LABEL "Reset";
    DEFINITION
    {
        int iValue;

        phys_factory_reset = 32771;
        WriteCommand(write_phys_factory_reset);
        iValue = 1;
        while(iValue == 1)
        {
            ReadCommand (read_phys_factory_reset);
            iValue = ivar_value(phys_factory_reset);
        }
        if (iValue == 0) PUT_MESSAGE("Finished.");
    }
}

METHOD method_TT_1_rtd_calibration
{
    LABEL "RTD Calibration";
    DEFINITION
    {
        int fValue;
        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            trans1_TT_1_Two_Wires_Comp = 5;
            WriteCommand(write_trans1_TT_1_Two_Wires_Comp);
            DELAY_TIME(4);
            fValue = 1;
            while(fValue == 1)
            {
                ReadCommand (read_trans1_TT_1_Two_Wires_Comp);
                fValue = ivar_value(trans1_TT_1_Two_Wires_Comp);
            }
            if (fValue == 0) PUT_MESSAGE("Finished.");
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");
        }
    }
}

METHOD method_TT_1_rtd_normal_comp
{
    LABEL "RTD Normal Temperature Compensation";
    DEFINITION
    {
        int fValue;
        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            trans1_TT_1_Two_Wires_Comp = 4;
            WriteCommand(write_trans1_TT_1_Two_Wires_Comp);
            DELAY_TIME(4);
            fValue = 1;
            while(fValue == 1)
            {
                ReadCommand (read_trans1_TT_1_Two_Wires_Comp);
                fValue = ivar_value(trans1_TT_1_Two_Wires_Comp);
            }
            if (fValue == 0) PUT_MESSAGE("Finished.");
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");
        }
    }
}

METHOD method_TT_1_rtd_high_comp
{
    LABEL "RTD High Temperature Compensation";
    DEFINITION
    {
        int fValue;
        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            trans1_TT_1_Two_Wires_Comp = 3;
            WriteCommand(write_trans1_TT_1_Two_Wires_Comp);
            DELAY_TIME(4);
            fValue = 1;
            while(fValue == 1)
            {
                ReadCommand (read_trans1_TT_1_Two_Wires_Comp);
                fValue = ivar_value(trans1_TT_1_Two_Wires_Comp);
            }
            if (fValue == 0) PUT_MESSAGE("Finished.");
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");
        }
    }
}

METHOD method_TT_1_rtd_low_comp
{
    LABEL "RTD Low Temperature Compensation";
    DEFINITION
    {
        int fValue;
        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            trans1_TT_1_Two_Wires_Comp = 2;
            WriteCommand(write_trans1_TT_1_Two_Wires_Comp);
            DELAY_TIME(4);
            fValue = 1;
            while(fValue == 1)
            {
                ReadCommand (read_trans1_TT_1_Two_Wires_Comp);
                fValue = ivar_value(trans1_TT_1_Two_Wires_Comp);
            }
            if (fValue == 0) PUT_MESSAGE("Finished.");
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");
        }
    }
}

METHOD method_TT_1_TC_full_comp
{
    LABEL "TC Full Compensation";
    DEFINITION
    {
        int fValue;
        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            trans1_TT_1_Two_Wires_Comp = 6;
            WriteCommand(write_trans1_TT_1_Two_Wires_Comp);
            DELAY_TIME(4);
            fValue = 1;
            while(fValue == 1)
            {
                ReadCommand (read_trans1_TT_1_Two_Wires_Comp);
                fValue = ivar_value(trans1_TT_1_Two_Wires_Comp);
            }
            if (fValue == 0) PUT_MESSAGE("Finished.");
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");
        }
    }
}

METHOD method_TT_1_TC_calibration
{
    LABEL "TC Calibration";
    DEFINITION
    {
        int fValue;
        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            trans1_TT_1_Two_Wires_Comp = 7;
            WriteCommand(write_trans1_TT_1_Two_Wires_Comp);
            DELAY_TIME(4);
            fValue = 1;
            while(fValue == 1)
            {
                ReadCommand (read_trans1_TT_1_Two_Wires_Comp);
                fValue = ivar_value(trans1_TT_1_Two_Wires_Comp);
            }
            if (fValue == 0) PUT_MESSAGE("Finished.");
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");
        }
    }
}

METHOD method_set_trans1_TT_1_cal_point_lo
{
    LABEL        [MC_Start];
    DEFINITION
    {
        int ret,fValue;

        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            ret = GET_DEV_VAR_VALUE("Enter applied temperature value", trans1_TT_1_Cal_Point_Lo);
            fValue = trans1_TT_1_Cal_Point_Lo;

            if (ret < 0)
            {
                process_abort();
            }

            WriteCommand (write_trans1_TT_1_Cal_Point_Lo);
            ReadCommand (read_trans1_TT_1_Cal_Point_Lo);
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");
        }

    }
}

METHOD method_set_trans1_TT_1_cal_point_hi
{
    LABEL        [MC_Start];
    DEFINITION
    {
        int ret,fValue;

        if (func1_AI_1_simulation_enabled == 0)        //0 = [off]
        {
            ret = GET_DEV_VAR_VALUE("Enter applied temperature value", trans1_TT_1_Cal_Point_Hi);
            fValue = trans1_TT_1_Cal_Point_Hi;

            if (ret < 0)
            {
                process_abort();
            }

            WriteCommand (write_trans1_TT_1_Cal_Point_Hi);
            ReadCommand (read_trans1_TT_1_Cal_Point_Hi);
        }
        else
        {
            ACKNOWLEDGE("Function not permitted during simulation");
        }

    }
}
